"use strict";

function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireWildcard(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _classnames = _interopRequireDefault(require("classnames"));
var _bind = _interopRequireDefault(require("classnames/bind"));
var _terraThemeContext = _interopRequireDefault(require("terra-theme-context"));
var _reactIntl = require("react-intl");
var _keycodeJs = require("keycode-js");
var _SwitchUtils = require("./_SwitchUtils");
var _SwitchModule = _interopRequireDefault(require("./Switch.module.scss"));
var _excluded = ["isChecked", "isDisabled", "isBlock", "onChange", "labelText"];
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != _typeof(e) && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && Object.prototype.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
var cx = _bind.default.bind(_SwitchModule.default);
var SWITCH_STATE = Object.freeze({
  ON: /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, {
    id: "Terra.switch.switchstatuslabel.on"
  }),
  OFF: /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, {
    id: "Terra.switch.switchstatuslabel.off"
  })
});
var propTypes = {
  /**
   * Whether or not the Switch is checked ("ON").
   */
  isChecked: _propTypes.default.bool,
  /**
   * Whether or not the Switch is disabled.
   */
  isDisabled: _propTypes.default.bool,
  /**
   * The label text of the Switch component.
   */
  labelText: _propTypes.default.string.isRequired,
  /**
   * Whether or not to render the switch as block element when specified.
   */
  isBlock: _propTypes.default.bool,
  /**
   * Callback function when switch value changes from ON / OFF.
   * Returns Parameters: 1. switch value 2. event.
   */
  onChange: _propTypes.default.func
};
var defaultProps = {
  isChecked: false,
  isDisabled: false,
  isBlock: false,
  onChange: undefined
};
var Switch = function Switch(props) {
  var isChecked = props.isChecked,
    isDisabled = props.isDisabled,
    isBlock = props.isBlock,
    onChange = props.onChange,
    labelText = props.labelText,
    customProps = _objectWithoutProperties(props, _excluded);
  var theme = _react.default.useContext(_terraThemeContext.default);
  var sliderButton = (0, _react.useRef)();
  var handleOnClick = (0, _react.useCallback)(function (event) {
    // Need this for focus styles on IE running on OS X since it does not receive focus when clicked.
    sliderButton.current.focus();
    if (onChange) {
      onChange(!isChecked, event);
    }
  }, [isChecked, onChange]);
  var handleOnKeyDown = function handleOnKeyDown(event) {
    if (event.nativeEvent.keyCode === _keycodeJs.KEY_RETURN || event.nativeEvent.keyCode === _keycodeJs.KEY_SPACE) {
      event.preventDefault();
      (0, _SwitchUtils.restoreFocusStyles)(sliderButton.current);
      if (onChange) {
        onChange(!isChecked, event);
      }
    }
  };
  var handleOnMouseDown = function handleOnMouseDown(event) {
    event.preventDefault();
    (0, _SwitchUtils.removeFocusStyles)(sliderButton.current);
  };
  var handleOnBlur = function handleOnBlur() {
    (0, _SwitchUtils.restoreFocusStyles)(sliderButton.current);
  };
  var statusLabelText = isChecked ? SWITCH_STATE.ON : SWITCH_STATE.OFF;
  var switchClassNames = (0, _classnames.default)(cx('switch', {
    'is-enabled': !isDisabled
  }, {
    'is-disabled': isDisabled
  }, {
    'is-selected': isChecked
  }, {
    'is-block': isBlock
  }, theme.className), customProps.className);
  var labelContainerClassNames = cx(['label-container', {
    'is-block': isBlock
  }]);
  var switchAttrs;
  if (!isDisabled) {
    switchAttrs = {
      tabIndex: '0',
      onBlur: handleOnBlur,
      onClick: handleOnClick,
      onMouseDown: handleOnMouseDown,
      onKeyDown: handleOnKeyDown
    };
  } else {
    switchAttrs = {
      'aria-disabled': true
    };
  }
  return /*#__PURE__*/_react.default.createElement("div", _extends({}, customProps, switchAttrs, {
    "aria-label": labelText,
    "aria-checked": isChecked,
    role: "switch",
    className: switchClassNames,
    "data-terra-switch-show-focus-styles": true,
    ref: sliderButton
  }), /*#__PURE__*/_react.default.createElement("div", {
    "aria-hidden": true,
    className: labelContainerClassNames
  }, /*#__PURE__*/_react.default.createElement("div", {
    className: cx('label-text')
  }, labelText), /*#__PURE__*/_react.default.createElement("div", {
    className: cx('status-label-text')
  }, statusLabelText)), /*#__PURE__*/_react.default.createElement("div", {
    "aria-hidden": true,
    className: cx('tray')
  }, /*#__PURE__*/_react.default.createElement("div", {
    className: cx('slider')
  })));
};
Switch.propTypes = propTypes;
Switch.defaultProps = defaultProps;
var _default = exports.default = Switch;